@@ -1,3 +1,9 @@
+# @package      hubzero-simtool
+# @file         params.py
+# @copyright    Copyright (c) 2019-2021 The Regents of the University of California.
+# @license      http://opensource.org/licenses/MIT MIT
+# @trademark    HUBzero is a registered trademark of The Regents of the University of California.
+#
 import os
 import numpy as np
 from mendeleev import element
@@ -636,7 +642,13 @@ class Image(Params):
                 try:
                     self._imageFormat = newval.format
                 except:
-                    pass
+                    if   type(newval) is list:
+                        self._value = newval
+                    elif type(newval) is np.ndarray:
+                        self._value = newval.tolist()
+#                   else:
+#                       print("Image.value: format failed")
+#                       print("type(newval): %s" % (type(newval)))
                 else:
                     self._value = np.array(newval).tolist()
 
