@@ -1,3 +1,9 @@
+# @package      hubzero-simtool
+# @file         run.py
+# @copyright    Copyright (c) 2019-2021 The Regents of the University of California.
+# @license      http://opensource.org/licenses/MIT MIT
+# @trademark    HUBzero is a registered trademark of The Regents of the University of California.
+#
 import os
 import uuid
 import copy
@@ -458,28 +464,26 @@ class Run:
        If the tool is not published, and cache is True, a local user cache will be used.
 
        Args:
-           simToolLocation:  A list containing information on SimTool notebook
+           simToolLocation: A dictionary containing information on SimTool notebook
                location and status.
-           inputs:  A SimTools Params object or a dictionary of key-value pairs.
-           runName:  An optional name for the run.  A unique name will be generated
+           inputs: A SimTools Params object or a dictionary of key-value pairs.
+           runName: An optional name for the run.  A unique name will be generated
                if no name is supplied.
-           remoteAttributes:  A list of parameters used for submission to offsite
+           remoteAttributes: A list of parameters used for submission to offsite
                resource.  In the absense of remoteAttributes the notebook execution
                will occur locally.
-           cache:  If the SimTool was run with the same inputs previously, return
+           cache: If the SimTool was run with the same inputs previously, return
                the results from the cache.  Otherwise cache the results.  If this
                parameter is False, do neither of these.  The SimTool must be published
                to access the global cache, otherwise each user has a local cache
                that can be accesed.
-           venue:  'noSubmit' to ignore presense of submit.
-                   'local' to use 'submit --local'.
-                   'trustedLocal' to use 'submit --local' as the trusted user for 
-                       global cache interaction.
-                   'remote' to use 'submit' to execute job on remote resource.
-                   'trustedRemote' to use 'submit' to execute job on remote resource
-                       as the trusted user for global cache interaction.
-                   Default is None, in which case venue is determined based on the
-                   availability of submit and the other arguments.
+           venue: [None, noSubmit, local, trustedLocal, remote, trustedRemote] venue selection mode.
+               noSubmit - to ignore presense of submit.
+               local - to use 'submit --local'.
+               trustedLocal - to use 'submit --local' as the trusted user for global cache interaction.
+               remote - to use 'submit' to execute job on remote resource.
+               trustedRemote - to use 'submit' to execute job on remote resource as the trusted user for global cache interaction.
+               None - venue is determined based on the availability of submit and the other arguments.
        Returns:
            A Run object.
        """
